@@ -1,4 +1,4 @@
-/* $Id: visual.c,v 1.7 2004/09/13 16:19:59 cegger Exp $
+/* $Id: visual.c,v 1.13 2005/09/01 22:32:03 cegger Exp $
 ******************************************************************************
 
    LibGGI - fbdev mga2164w acceleration
@@ -32,8 +32,10 @@
 /* The default LibGGI font */
 #include <ggi/internal/font/8x8>
 
+#include <ggi/internal/ggi_debug.h>
 
-static int m2164w_acquire(ggi_resource *res, uint32 actype)
+
+static int m2164w_acquire(ggi_resource *res, uint32_t actype)
 {
 	ggi_visual *vis;
 
@@ -66,7 +68,7 @@ static int m2164w_release(ggi_resource *res)
 static int
 m2164w_idleaccel(ggi_visual *vis)
 {
-	GGIDPRINT_DRAW("m2164w_idleaccel(%p) called \n", vis);
+	DPRINT_DRAW("m2164w_idleaccel(%p) called \n", vis);
 
 	mga_waitidle(FBDEV_PRIV(vis)->mmioaddr);
 	
@@ -82,7 +84,7 @@ static int do_cleanup(ggi_visual *vis)
 	struct m2164w_priv *priv = NULL;
 	int i;
 
-	GGIDPRINT_MISC("mga-2164w: Starting cleanup\n");
+	DPRINT_MISC("mga-2164w: Starting cleanup\n");
 
 	if (fbdevpriv != NULL) {
 		priv = M2164W_PRIV(vis);
@@ -100,7 +102,7 @@ static int do_cleanup(ggi_visual *vis)
 	mga_waitidle(fbdevpriv->mmioaddr);
 
 	munmap((void*)fbdevpriv->mmioaddr, fbdevpriv->orig_fix.mmio_len);
-	GGIDPRINT_MISC("mga-2164w: Unmapped MMIO\n");
+	DPRINT_MISC("mga-2164w: Unmapped MMIO\n");
 
 	/* Free DB resource structures */
 	for (i = LIBGGI_APPLIST(vis)->num-1; i >= 0; i--) {
@@ -111,7 +113,7 @@ static int do_cleanup(ggi_visual *vis)
 	}
 
 	free(priv);
-	M2164W_PRIV(vis) = NULL;
+	FBDEV_PRIV(vis)->accelpriv = NULL;
 
 	ggUnregisterCleanup((ggcleanup_func *)do_cleanup, vis);
 
@@ -120,7 +122,7 @@ static int do_cleanup(ggi_visual *vis)
 	
 
 static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
-		   const char *args, void *argptr, uint32 *dlret)
+		   const char *args, void *argptr, uint32_t *dlret)
 {
 	ggi_fbdev_priv *fbdevpriv = FBDEV_PRIV(vis);
 	struct m2164w_priv *priv;
@@ -148,7 +150,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 				   fd, (signed)fbdevpriv->orig_fix.smem_len);
 	if (fbdevpriv->mmioaddr == MAP_FAILED) {
 		/* Can't mmap() MMIO region - bail out */
-		GGIDPRINT_LIBS("mga-2164w: Unable to map MMIO region: %s\n"
+		DPRINT_LIBS("mga-2164w: Unable to map MMIO region: %s\n"
 			       "          fd: %d, len: %ld, offset: %ld\n",
 			       strerror(errno), fd,
 			       fbdevpriv->orig_fix.mmio_len,
@@ -158,7 +160,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		return GGI_ENODEVICE;
 	}
 
-	GGIDPRINT_MISC("mga-2164w: Mapped MMIO region at %p\n",
+	DPRINT_MISC("mga-2164w: Mapped MMIO region at %p\n",
 		       fbdevpriv->mmioaddr);
 
 	/* Set up DirectBuffers */
@@ -213,27 +215,27 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 	fbdevpriv->idleaccel = m2164w_idleaccel;
 
 	/* Accelerate fonts if possible */
-	priv->font = (uint8 *)(font);
+	priv->font = (uint8_t *)(font);
 	usedmemend = LIBGGI_MODE(vis)->frames *
 		fbdevpriv->fix.line_length * LIBGGI_VIRTY(vis);
 	fontlen = 256*8;
 	priv->fontoffset = fbdevpriv->orig_fix.smem_len - fontlen;
 	priv->fontoffset &= ~127; /* Align */
-	GGIDPRINT_MISC("mga-2164w: usedmemend: %ld, fontoffset: %ld\n",
+	DPRINT_MISC("mga-2164w: usedmemend: %ld, fontoffset: %ld\n",
 		       usedmemend, priv->fontoffset);
 	if (usedmemend <= priv->fontoffset) {
-		memcpy((uint8*)fbdevpriv->fb_ptr + priv->fontoffset,
+		memcpy((uint8_t*)fbdevpriv->fb_ptr + priv->fontoffset,
 		       font, fontlen);
 		priv->fontoffset *= 8; /* In bits */
 		priv->charadd = FWIDTH*FHEIGHT;
 		vis->opdraw->putc = GGI_m2164w_fastputc;
 		vis->opdraw->puts = GGI_m2164w_fastputs;
-		GGIDPRINT_MISC("mga-2164w: Using fast chars\n");
+		DPRINT_MISC("mga-2164w: Using fast chars\n");
 	} else {
 		priv->fontoffset = 0;
 		vis->opdraw->putc = GGI_m2164w_putc;
 		vis->opdraw->puts = GGI_m2164w_puts;
-		GGIDPRINT_MISC("mga-2164w: Using slow chars\n");
+		DPRINT_MISC("mga-2164w: Using slow chars\n");
 	}
 
 	/* Save previous function pointers */
@@ -253,7 +255,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		vis->opdraw->crossblit = GGI_m2164w_crossblit;
 	}
 
-	M2164W_PRIV(vis) = priv;
+	FBDEV_PRIV(vis)->accelpriv = priv;
 
 	/* Register cleanup handler */
 	ggRegisterCleanup((ggcleanup_func *)do_cleanup, vis);
@@ -270,19 +272,19 @@ static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
 
 
 EXPORTFUNC
-int GGIdl_m2164w(int func, void **funcptr);
+int GGIdl_fbdev_m2164w(int func, void **funcptr);
 
-int GGIdl_m2164w(int func, void **funcptr)
+int GGIdl_fbdev_m2164w(int func, void **funcptr)
 {
 	switch (func) {
 	case GGIFUNC_open:
-		*funcptr = GGIopen;
+		*funcptr = (void *)GGIopen;
 		return 0;
 	case GGIFUNC_exit:
 		*funcptr = NULL;
 		return 0;
 	case GGIFUNC_close:
-		*funcptr = GGIclose;
+		*funcptr = (void *)GGIclose;
 		return 0;
 	default:
 		*funcptr = NULL;
