@@ -1,4 +1,4 @@
-/* $Id: visual.c,v 1.2.2.1 2004/11/14 20:54:32 cegger Exp $
+/* $Id: visual.c,v 1.6 2005/09/01 22:36:09 cegger Exp $
 ******************************************************************************
 
    ATI Mach64 acceleration sublib for kgi display target
@@ -40,7 +40,7 @@ static int GGI_kgi_mach64_flush(ggi_visual *vis, int x, int y,
 
 
 static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
-			const char *args, void *argptr, uint32 *dlret)
+			const char *args, void *argptr, uint32_t *dlret)
 {
 	ggi_accel_t *accel;
 
@@ -92,13 +92,13 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 
 
 EXPORTFUNC
-int GGIdl_mach64(int func, void **funcptr);
+int GGIdl_kgi_mach64(int func, void **funcptr);
 
-int GGIdl_mach64(int func, void **funcptr)
+int GGIdl_kgi_mach64(int func, void **funcptr)
 {
 	switch (func) {
 	case GGIFUNC_open:
-		*funcptr = GGIopen;
+		*funcptr = (void *)GGIopen;
 		return 0;
 	case GGIFUNC_exit:
 	case GGIFUNC_close:
