@@ -1,4 +1,4 @@
-/* $Id: visual.c,v 1.10.2.2 2004/11/14 20:50:19 cegger Exp $
+/* $Id: visual.c,v 1.16 2005/09/01 22:36:09 cegger Exp $
 ******************************************************************************
 
    ATI Radeon acceleration sublib for kgi display target
@@ -63,9 +63,9 @@ static int rwframes_changed_3d(ggi_visual *vis) {
 	radeon_context_t *ctx;
 	struct {
 		cce_type0_header_t h1;
-		uint32 txoffset;
+		uint32_t txoffset;
 		cce_type0_header_t h2;
-		uint32 coloroffset;
+		uint32_t coloroffset;
 	} packet;
 
 	ctx = KGI_ACCEL_PRIV(vis);
@@ -92,7 +92,7 @@ static int origin_changed(ggi_visual *vis) {
 	ggi_graphtype gt;
 	struct {
 		cce_type0_header_t h1;
-		uint32 crtc_offset;
+		uint32_t crtc_offset;
 	} packet;
 
         db = _ggi_db_find_frame(vis, vis->d_frame_num);
@@ -128,7 +128,7 @@ static int origin_changed(ggi_visual *vis) {
 
 
 static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
-		   const char *args, void *argptr, uint32 *dlret)
+		   const char *args, void *argptr, uint32_t *dlret)
 {
 	ggi_accel_t *accel;
 	radeon_context_t *ctx;
@@ -296,7 +296,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 
 	/* If the mode is compatible, use the 3D engine */ 
 	if (use3d) {	
-		GGIDPRINT("Using 3D engine.\n");
+		DPRINT("Using 3D engine.\n");
 		vis->opdraw->drawline     = GGI_kgi_radeon_drawline_3d;
 		vis->opdraw->drawbox      = GGI_kgi_radeon_drawbox_3d;
 		vis->opdraw->copybox      = GGI_kgi_radeon_copybox_3d;
@@ -306,7 +306,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		 * The base KGI code will send -1 or a large enough swatch.
 		 */
 		if (KGI_PRIV(vis)->swatch_size >= 0) {
-			GGIDPRINT("Accelerating Put* functions.\n");
+			DPRINT("Accelerating Put* functions.\n");
 			vis->opdraw->putc        = GGI_kgi_radeon_putc_3d;
 			vis->opdraw->puts        = GGI_kgi_radeon_puts_3d;
 			vis->opdraw->putbox      = GGI_kgi_radeon_putbox_3d;
@@ -316,7 +316,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		}
 		KGI_PRIV(vis)->rwframes_changed = rwframes_changed_3d;
 	} else {
-		GGIDPRINT("Using 2D GUI engine.\n");
+		DPRINT("Using 2D GUI engine.\n");
 		vis->opdraw->drawline     = GGI_kgi_radeon_drawline_2d;
 		vis->opdraw->drawbox      = GGI_kgi_radeon_drawbox_2d;
 		vis->opdraw->copybox      = GGI_kgi_radeon_copybox_2d;
@@ -343,17 +343,17 @@ static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
 }
 
 EXPORTFUNC
-int GGIdl_radeon(int func, void **funcptr);
+int GGIdl_kgi_radeon(int func, void **funcptr);
 
-int GGIdl_radeon(int func, void **funcptr)
+int GGIdl_kgi_radeon(int func, void **funcptr)
 {
 	switch (func) {
 	case GGIFUNC_open:
-		*funcptr = GGIopen;
+		*funcptr = (void *)GGIopen;
 		return 0;
 	case GGIFUNC_exit:
 	case GGIFUNC_close:
-		*funcptr = GGIclose;
+		*funcptr = (void *)GGIclose;
 		return 0;
 	default:
 		*funcptr = NULL;
