@@ -1,4 +1,4 @@
-/* $Id: visual.c,v 1.5.2.1 2004/11/14 20:56:28 cegger Exp $
+/* $Id: visual.c,v 1.9 2005/09/01 22:36:09 cegger Exp $
 ******************************************************************************
 
    Matrox Gx00 acceleration sublib for kgi display target
@@ -55,7 +55,7 @@ static int GGI_kgi_Gx00_flush(ggi_visual *vis, int x, int y,
 }
 
 static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
-			const char *args, void *argptr, uint32 *dlret)
+			const char *args, void *argptr, uint32_t *dlret)
 {
 	ggi_accel_t *accel;
 	Gx00_context_t *ctx;
@@ -81,7 +81,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 	GX00_WRITE_REG(vis, LIBGGI_VIRTX(vis), PITCH);
 	/* Initializes the MACCESS fields */
 	{
-	  uint32 maccess = MACCESS_ZWIDTH_ZW16; /* NB: no fogging */
+	  uint32_t maccess = MACCESS_ZWIDTH_ZW16; /* NB: no fogging */
 	  switch (GT_ByPP(LIBGGI_GT(vis))) {
 	  case 1:
 	    maccess |= MACCESS_PWIDTH_PW8;
@@ -158,17 +158,17 @@ static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
 }
 
 EXPORTFUNC
-int GGIdl_Gx00(int func, void **funcptr);
+int GGIdl_kgi_Gx00(int func, void **funcptr);
 
-int GGIdl_Gx00(int func, void **funcptr)
+int GGIdl_kgi_Gx00(int func, void **funcptr)
 {
 	switch (func) {
 	case GGIFUNC_open:
-		*funcptr = GGIopen;
+		*funcptr = (void *)GGIopen;
 		return 0;
 	case GGIFUNC_exit: /* TODO: Check if exit is also there */
 	case GGIFUNC_close:
-		*funcptr = GGIclose;
+		*funcptr = (void *)GGIclose;
 		return 0;
 	default:
 		*funcptr = NULL;
