@@ -1,4 +1,4 @@
-/* $Id: visual.c,v 1.3 2004/02/23 14:24:45 pekberg Exp $
+/* $Id: visual.c,v 1.5 2005/07/30 11:40:00 cegger Exp $
 ******************************************************************************
 
    Linear 1 bit graphics (high-bit-left)
@@ -31,7 +31,7 @@
 
 
 static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
-			const char *args, void *argptr, uint32 *dlret)
+			const char *args, void *argptr, uint32_t *dlret)
 {
 	/* Color mapping 
 	 */
@@ -78,7 +78,7 @@ int GGIdl_linear_1(int func, void **funcptr)
 {
 	switch (func) {
 	case GGIFUNC_open:
-		*funcptr = GGIopen;
+		*funcptr = (void *)GGIopen;
 		return 0;
 	case GGIFUNC_exit:
 	case GGIFUNC_close:
