@@ -1,4 +1,4 @@
-/* $Id: fillscreen.c,v 1.4 2004/09/13 09:23:49 cegger Exp $
+/* $Id$
 ******************************************************************************
 
    Graphics library for GGI. Fillscreenfunctions for X.
@@ -28,11 +28,13 @@
 #include "config.h"
 #include <ggi/internal/ggi-dl.h>
 #include <ggi/display/x.h>
+#include <ggi/internal/ggi_debug.h>
 
 int GGI_X_fillscreen_slave(ggi_visual *vis) {
 	ggi_x_priv *priv;
 	priv = GGIX_PRIV(vis);
 
+	DPRINT("X_fillscreen_slave enter!\n");
 	if (LIBGGI_GC(vis)->cliptl.x > 0
 	    || LIBGGI_GC(vis)->cliptl.y > 0
 	    || LIBGGI_GC(vis)->clipbr.x < LIBGGI_VIRTX(vis)
@@ -52,11 +54,21 @@ int GGI_X_fillscreen_slave(ggi_visual *vis) {
 int GGI_X_fillscreen_slave_draw(ggi_visual *vis)
 {
 	ggi_x_priv *priv;
+	XGCValues gcValue;
+	GC gc;
+
 	priv = GGIX_PRIV(vis);
 
-	ggLock(priv->xliblock);
-	XSetWindowBackground(priv->disp, priv->drawable,
-			     LIBGGI_GC(vis)->fg_color);
+	DPRINT("X_fillscreen_slave_draw enter!\n");
+
+	GGI_X_LOCK_XLIB(vis);
+	
+	/* XXX: What is priv->gc ?  is it appropriate to use that here? */
+	gcValue.foreground = LIBGGI_GC(vis)->fg_color;
+	gcValue.background = LIBGGI_GC(vis)->fg_color;
+	gcValue.function   = GXcopy;
+	gc = XCreateGC( priv->disp, priv->drawable,
+	 		GCForeground | GCBackground | GCFunction, &gcValue);
 
 	if (LIBGGI_GC(vis)->cliptl.x > 0
 	    || LIBGGI_GC(vis)->cliptl.y > 0
@@ -64,25 +76,40 @@ int GGI_X_fillscreen_slave_draw(ggi_visual *vis)
 	    || LIBGGI_GC(vis)->clipbr.y < LIBGGI_VIRTY(vis)) {
 		int y;
 
+		DPRINT("X_fillscreen_slave_draw small clip!\n");
 		GGI_X_CLEAN(vis, 
 			    LIBGGI_GC(vis)->cliptl.x, LIBGGI_GC(vis)->cliptl.y,
 			    LIBGGI_GC(vis)->clipbr.x-LIBGGI_GC(vis)->cliptl.x,
 			    LIBGGI_GC(vis)->clipbr.y-LIBGGI_GC(vis)->cliptl.y);
+		DPRINT("X_fillscreen_slave_draw calling opdraw->fillscreen\n");
 		priv->slave->opdraw->fillscreen(priv->slave);
+		/* What is this?  y is set twice?  which value is 
+		 * proper?  Answer: GGI_X_WRITE_Y is a macro that makes
+		 * use of the value stored in y. */
 		y = LIBGGI_GC(vis)->cliptl.y;
 		y = GGI_X_WRITE_Y;
-		XClearArea(priv->disp, priv->drawable,
-			   LIBGGI_GC(vis)->cliptl.x, y,
-			   (unsigned)LIBGGI_GC(vis)->clipbr.x-LIBGGI_GC(vis)->cliptl.x,
-			   (unsigned)LIBGGI_GC(vis)->clipbr.y-LIBGGI_GC(vis)->cliptl.y, 
-			   False);
+
+#define CLIPSIZE(xy) \
+		(unsigned)LIBGGI_GC(vis)->clipbr.xy-LIBGGI_GC(vis)->cliptl.xy
+
+		XFillRectangle(priv->disp, priv->drawable, 
+			gc, 
+		        LIBGGI_GC(vis)->cliptl.x, y,
+			CLIPSIZE(x),
+			CLIPSIZE(y)
+			);
 	} else {
+		DPRINT("X_fillscreen_slave_draw large clip!\n");
 		GGI_X_CLEAN(vis, 0, 0, LIBGGI_VIRTX(vis), LIBGGI_VIRTY(vis));
+		DPRINT("X_fillscreen_slave_draw calling opdraw->fillscreen\n");
 		priv->slave->opdraw->fillscreen(priv->slave);
-		XClearWindow(priv->disp, priv->drawable);
+		XFillRectangle(priv->disp, priv->drawable, 
+			gc, 0, 0, LIBGGI_VIRTX(vis), LIBGGI_VIRTY(vis) );
 	}
 	GGI_X_MAYBE_SYNC(vis);
-	ggUnlock(priv->xliblock);
+	XFreeGC(priv->disp, gc);
+
+	GGI_X_UNLOCK_XLIB(vis);
 	return GGI_OK;
 }
 
@@ -90,29 +117,46 @@ int GGI_X_fillscreen_slave_draw(ggi_visual *vis)
 int GGI_X_fillscreen_draw(ggi_visual *vis)
 {
 	ggi_x_priv *priv;
+	XGCValues gcValue;
+	GC gc;
 	priv = GGIX_PRIV(vis);
 
-	ggLock(priv->xliblock);
-	XSetWindowBackground(priv->disp, priv->drawable,
-			     LIBGGI_GC(vis)->fg_color);
+	DPRINT("X_fillscreen_draw enter!\n");
+
+	GGI_X_LOCK_XLIB(vis);
+	
+	/* XXX: What is priv->gc ?  is it appropriate to use that here? */
+	gcValue.foreground = LIBGGI_GC(vis)->fg_color;
+	gcValue.background = LIBGGI_GC(vis)->fg_color;
+	gcValue.function   = GXcopy;
+	gc = XCreateGC( priv->disp, priv->drawable,
+	 		GCForeground | GCBackground | GCFunction, &gcValue);
 
 	if (LIBGGI_GC(vis)->cliptl.x > 0
 	    || LIBGGI_GC(vis)->cliptl.y > 0
 	    || LIBGGI_GC(vis)->clipbr.x < LIBGGI_VIRTX(vis)
 	    || LIBGGI_GC(vis)->clipbr.y < LIBGGI_VIRTY(vis)) {
 		int y;
+		/* Note: GGI_X_WRITE_Y is a macro that makes use
+		 * of the value stored in y. */
 		y = LIBGGI_GC(vis)->cliptl.y;
 		y = GGI_X_WRITE_Y;
-		XClearArea(priv->disp, priv->drawable,
-			   LIBGGI_GC(vis)->cliptl.x, y,
-			   (unsigned)LIBGGI_GC(vis)->clipbr.x-LIBGGI_GC(vis)->cliptl.x,
-			   (unsigned)LIBGGI_GC(vis)->clipbr.y-LIBGGI_GC(vis)->cliptl.y, 
-			   False);
+
+		/* CLIPSIZE macro is defined above in 
+		 * GGI_X_fillscreen_slave_draw() */
+		XFillRectangle(priv->disp, priv->drawable, 
+			gc, 
+		        LIBGGI_GC(vis)->cliptl.x, y,
+			CLIPSIZE(x),
+			CLIPSIZE(y)
+			);
 	} else {
-		XClearWindow(priv->disp, priv->drawable);
+		XFillRectangle(priv->disp, priv->drawable, 
+			gc, 0, 0, LIBGGI_VIRTX(vis), LIBGGI_VIRTY(vis) );
 	}
 	GGI_X_MAYBE_SYNC(vis);
-	ggUnlock(priv->xliblock);
+	GGI_X_UNLOCK_XLIB(vis);
 
+	DPRINT_LIBS("X_fillscreen_draw exit!\n");
 	return 0;
 }
