@@ -1,4 +1,4 @@
-/* $Id: visual.c,v 1.34.2.2 2004/11/14 20:55:11 cegger Exp $
+/* $Id$
 ******************************************************************************
 
    LibGGI Display-X target: initialization
@@ -34,7 +34,10 @@
 
 #include "config.h"
 #include <ggi/internal/ggi-dl.h>
+#include <ggi/internal/ggi_debug.h>
 #include <ggi/display/x.h>
+#include <ggi/internal/gg_replace.h>
+
 
 /* Options honored by this target */
 static const gg_option optlist[] =
@@ -114,7 +117,7 @@ void GGI_X_gcchanged(ggi_visual *vis, int mask)
 
  noslave:
 	if ((mask & GGI_GCCHANGED_CLIP)) {
-		ggLock(priv->xliblock);
+		GGI_X_LOCK_XLIB(vis);
 		_ggi_x_set_xclip(vis, priv->disp, priv->gc,
 				 LIBGGI_GC(vis)->cliptl.x, 
 				 LIBGGI_GC(vis)->cliptl.y,
@@ -122,17 +125,17 @@ void GGI_X_gcchanged(ggi_visual *vis, int mask)
 				 LIBGGI_GC(vis)->cliptl.x,
 				 LIBGGI_GC(vis)->clipbr.y -
 				 LIBGGI_GC(vis)->cliptl.y);
-		ggUnlock(priv->xliblock);
+		GGI_X_UNLOCK_XLIB(vis);
 	}
 	if ((mask & GGI_GCCHANGED_FG)) {
-		ggLock(priv->xliblock);
+		GGI_X_LOCK_XLIB(vis);
 		XSetForeground(priv->disp, priv->gc, LIBGGI_GC_FGCOLOR(vis));
-		ggUnlock(priv->xliblock);
+		GGI_X_UNLOCK_XLIB(vis);
 	}
 	if ((mask & GGI_GCCHANGED_BG)) {
-		ggLock(priv->xliblock);
+		GGI_X_LOCK_XLIB(vis);
 		XSetBackground(priv->disp, priv->gc, LIBGGI_GC_BGCOLOR(vis));
-		ggUnlock(priv->xliblock);
+		GGI_X_UNLOCK_XLIB(vis);
 	}
 }
 
@@ -156,11 +159,27 @@ static int GGI_X_setflags(ggi_visual *vis, ggi_flags flags) {
 	return GGI_OK;
 }
 
+static void GGI_X_lock_xlib(ggi_visual *vis)
+{
+	ggi_x_priv *priv = GGIX_PRIV(vis);
+	ggLock(priv->xliblock);
+}
+
+static void GGI_X_unlock_xlib(ggi_visual *vis)
+{
+	ggi_x_priv *priv = GGIX_PRIV(vis);
+	if (ggTryLock(priv->flushlock) == 0)
+		vis->opdisplay->flush(vis, 0, 0, LIBGGI_VIRTX(vis), LIBGGI_VIRTY(vis), 2);
+	ggUnlock(priv->xliblock);
+}
+
 static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
 {
 	ggi_x_priv *priv;
 	priv = GGIX_PRIV(vis);
 
+	DPRINT_MISC("GGIclose(%p, %p) called\n", vis, dlh);
+
 	if (priv == NULL) goto skip;
 	if (priv->disp == NULL) goto skip2;
 
@@ -169,12 +188,14 @@ static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
 	if (priv->slave) ggiClose(priv->slave);
 	priv->slave = NULL;
 
+	DPRINT_MISC("GGIclose: call freefb hook\n");
 	if (priv->freefb) priv->freefb(vis);
 
 	/* Exit any initialized helper libs if called from GGIopen. */
-	if (vis->extlib) {
-		_ggiExitDL(vis, vis->extlib);
-		_ggiZapDL(vis, &vis->extlib);
+	DPRINT_MISC("GGIclose: close any helpers\n");
+	if (!GG_SLIST_EMPTY(&vis->extlib)) {
+		_ggiExitDL(vis, GG_SLIST_FIRST(&vis->extlib));
+		_ggiZapDL(vis, &GG_SLIST_FIRST(&vis->extlib));
 	}
 
 	if (priv->win != priv->parentwin) {
@@ -184,11 +205,13 @@ static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
 	if (!priv->parentwin) goto skip3;
 
 	/* Do special cleanup for -inwin and root windows */
-	if (vis->opdisplay->checkmode == GGI_X_checkmode_fixed) {
+	if ( ! priv->ok_to_resize )  {
 		unsigned int dummy;
 		Window root;
 		int screen;
 		XSetWindowAttributes wa;
+
+		DPRINT_MISC("GGIclose: special cleanup for -inwin and root windows\n");
 		
 		screen = priv->vilist[priv->viidx].vi->screen;
 		XGetGeometry(priv->disp, priv->parentwin, &root, (int *)&dummy,
@@ -207,32 +230,57 @@ static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
 	}
 
 skip3:
+	DPRINT_MISC("GGIclose: free colormaps\n");
 	_ggi_x_free_colormaps(vis);
 
+	DPRINT_MISC("GGIclose: free cursor\n");
 	if (priv->cursor != None)   XFreeCursor(priv->disp,priv->cursor);
+
+	DPRINT_MISC("GGIclose: free font\n");
 	if (priv->textfont != None) XFreeFont(priv->disp, priv->textfont);
 	if (priv->fontimg)	    XDestroyImage(priv->fontimg);
+
+	DPRINT_MISC("GGIclose: free X visual and buffers\n");
 	if (priv->visual)           XFree(priv->visual);
 	if (priv->buflist)	    XFree(priv->buflist);
+
+	DPRINT_MISC("GGIclose: close display\n");
 	if (priv->disp)		    XCloseDisplay(priv->disp);
+
+	DPRINT_MISC("GGIclose: free visual and mode list\n");
 	if (priv->vilist)	    free(priv->vilist);
 	if (priv->modes)	    free(priv->modes);
+
+	DPRINT_MISC("GGIclose: free mansync\n");
 	if (priv->opmansync)	    free(priv->opmansync);
  skip2:
+	DPRINT_MISC("GGIclose: destroy flushlock\n");
+	if (priv->flushlock)	    ggLockDestroy(priv->flushlock);
+	DPRINT_MISC("GGIclose: destroy xliblock\n");
 	if (priv->xliblock)	    ggLockDestroy(priv->xliblock);
 	free(priv);
  skip:
+	DPRINT_MISC("GGIclose: free GC\n");
 	if (LIBGGI_GC(vis) != NULL) free(LIBGGI_GC(vis));
-	GGIDPRINT_MISC("X-target closed\n");
+	DPRINT_MISC("X-target closed\n");
 	return 0;
 }
 
+/* prototypes for functions in mode.c that we need in 
+ * order to initialize xpriv->cm_adjust and xpriv->cm_adapt */
+void _GGI_X_checkmode_adapt( ggi_mode * m,
+			     ggi_x_vi * vi,
+			     ggi_x_priv * priv );
+void _GGI_X_checkmode_adjust( ggi_mode *req,
+			      ggi_mode *sug,
+			      ggi_x_priv *priv );
+
+
 static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
-		   const char *args, void *argptr, uint32 *dlret)
+		   const char *args, void *argptr, uint32_t *dlret)
 
 {
 	int err, tmp1, tmp2, tmp3;  /* Return value, scratch variables */
-	char 		*tmpstr;
 	XVisualInfo	vi_template;
 	long		vi_mask;
 	gg_option 	options[NUM_OPTS];
@@ -243,7 +291,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 	memcpy(options, optlist, sizeof(options));
 
 	if (args) {
-		args = ggParseOptions((char *)args, options, NUM_OPTS);
+		args = ggParseOptions(args, options, NUM_OPTS);
 		if (args == NULL) {
 			fprintf(stderr, "display-x: error in arguments.\n");
 			return GGI_EARGINVAL;
@@ -260,19 +308,27 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 	LIBGGI_PRIVATE(vis) = priv;
 	vis->gamma = &(priv->gamma);
 
+	/* Create a lock to regularly flush */
+	lock = ggLockCreate();
+	if (lock == NULL) goto out;
+	ggLock(lock);
+	priv->flushlock = lock;
+	priv->lock_xlib    = GGI_X_lock_xlib;
+	priv->unlock_xlib = GGI_X_unlock_xlib;
+
 	/* Create a lock to prevent concurrent Xlib access */
 	lock = ggLockCreate();
 	if (lock == NULL) goto out;
 	priv->xliblock = lock;
 
 	/* Obtain the X11 display handle */
-	GGIDPRINT_MISC("X: want display %s\n", args);
+	DPRINT_MISC("X: want display %s\n", args);
 	disp = XOpenDisplay(args);
 	if (disp == NULL) goto out;
-	GGIDPRINT_MISC("X: have display %s\n", DisplayString(disp));
-	GGIDPRINT_MISC("X: number of screens on this display: %i\n",
+	DPRINT_MISC("X: have display %s\n", DisplayString(disp));
+	DPRINT_MISC("X: number of screens on this display: %i\n",
 			ScreenCount(disp));
-	GGIDPRINT_MISC("X: defaultscreen on this display: %i\n",
+	DPRINT_MISC("X: defaultscreen on this display: %i\n",
 			DefaultScreen(disp));
 	priv->disp = disp;
 
@@ -284,13 +340,12 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 
 	/* See what extensions are available on this display. */
 #define GGI_X_CHECK_XEXT(extname, flag)					\
-	tmpstr = extname;						\
-	XQueryExtension(disp, tmpstr, &tmp1, &tmp2, &tmp3);		\
+	XQueryExtension(disp, extname, &tmp1, &tmp2, &tmp3);		\
 	if (tmp1) {							\
-		GGIDPRINT_MISC("%s X extension found\n", tmpstr);	\
+		DPRINT_MISC("%s X extension found\n", extname);		\
 		priv->use_Xext |= flag;					\
 	} else {							\
-		GGIDPRINT_MISC("no %s extension\n", tmpstr);		\
+		DPRINT_MISC("no %s extension\n", extname);		\
 	}
 	
 	GGI_X_CHECK_XEXT("Extended-Visual-Information",	GGI_X_USE_EVI);
@@ -333,19 +388,17 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		 * when both available. This is handled below.
 		 */
 
-		vis->opdisplay->checkmode = GGI_X_checkmode_normal;
-		vis->opdisplay->setmode = GGI_X_setmode_normal;
+		priv->ok_to_resize = 1;
 		if (options[OPT_INWIN].result[0] != 'n') {
 			XWindowAttributes wa;
 			priv->parentwin = priv->win =
 				strtol(options[OPT_INWIN].result, NULL, 0);
-			GGIDPRINT_MISC("X: using window id 0x%x\n", 
+			DPRINT_MISC("X: using window id 0x%x\n", 
 				       priv->parentwin);
 			vi_mask = VisualScreenMask;
 			XGetWindowAttributes(priv->disp, priv->parentwin, &wa);
 			vi_template.screen = XScreenNumberOfScreen(wa.screen);
-			vis->opdisplay->checkmode = GGI_X_checkmode_fixed;
-			vis->opdisplay->setmode = GGI_X_setmode_fixed;
+			priv->ok_to_resize = 0;
 		}
 	} else {
 		XWindowAttributes wa;
@@ -361,17 +414,16 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		XGetWindowAttributes(priv->disp, priv->win, &wa);
 		vi_mask = VisualIDMask | VisualScreenMask;
 		vi_template.visualid = XVisualIDFromVisual(wa.visual);
-		vis->opdisplay->checkmode = GGI_X_checkmode_fixed;
-		vis->opdisplay->setmode = GGI_X_setmode_fixed;
+		priv->ok_to_resize = 0;
 
-		GGIDPRINT_MISC("X: using root window of screen %u\n", 
+		DPRINT_MISC("X: using root window of screen %u\n", 
 			       vi_template.screen);
 	}
 
 	priv->visual = XGetVisualInfo(priv->disp, vi_mask, 
 				      &vi_template, &priv->nvisuals);
 	if (priv->visual == NULL || priv->nvisuals <= 0) {
-		GGIDPRINT("X: No acceptable X11 visuals.\n");
+		DPRINT("X: No acceptable X11 visuals.\n");
 		err = GGI_ENOFUNC;
 		goto out;
 	}
@@ -381,7 +433,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 	priv->buflist = XListPixmapFormats(disp, &(priv->nbufs));
 	if (priv->buflist == NULL) goto out;
 
-	GGIDPRINT_MISC("X: Sort/complete visual list.\n");
+	DPRINT_MISC("X: Sort/complete visual list.\n");
 	_ggi_x_build_vilist(vis);	/* Sorts/completes vilist */
 
 
@@ -397,24 +449,32 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		  _ggi_x_create_dot_cursor : _ggi_x_create_invisible_cursor; 
 	}
 
-	/* Set the rest of our default displayops. Helper libs may override. */
+	/* Set our default displayops. Helper libs may override. */
 	vis->opdisplay->getmode  = GGI_X_getmode;
 	vis->opdisplay->getapi   = GGI_X_getapi;
 	vis->opdisplay->setflags = GGI_X_setflags;
+	
+	vis->opdisplay->checkmode = GGI_X_checkmode;
+	vis->opdisplay->setmode = GGI_X_setmode;
+
+	/* An extension might want to overload these to provide different
+	 * Visual-based modes. */
+	priv->cm_adapt = _GGI_X_checkmode_adapt;
+	priv->cm_adjust = _GGI_X_checkmode_adjust;
 
 	/* Try the extensions that haven't been disabled. */
 #define GGI_X_TEST_XEXT(flag, helper, abort_label)		\
 	if (!(priv->use_Xext & flag)) goto abort_label;		\
-	tmpstr = helper;					\
-	err = _ggiAddDL(vis, tmpstr, NULL, NULL, 0);		\
+	err = _ggiAddDL(vis, _ggiGetConfigHandle(),		\
+			helper, NULL, NULL, 0);			\
 	if (err) {						\
-		fprintf(stderr, "X: Cannot load %s\n", tmpstr);	\
+		fprintf(stderr, "X: Cannot load %s\n", helper);	\
 		priv->use_Xext &= ~flag;			\
 		goto abort_label;				\
 	}
 
 
-	GGIDPRINT_MISC("X: Load X extensions.\n");
+	DPRINT_MISC("X: Load X extensions.\n");
 
 	/* Order is important here -- XCloseDisplay has sharp hooks! */
 
@@ -426,7 +486,6 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 	if (options[OPT_NOBUFFER].result[0] != 'n') goto noshm;
 	GGI_X_TEST_XEXT(GGI_X_USE_SHM, "helper-x-shm", noshm);
 	priv->shmhack_free_cmaps = _ggi_x_free_colormaps;
-	priv->shmhack_checkmode_fixed = GGI_X_checkmode_fixed;
 
  noshm:
 	priv->use_Xext &= ~GGI_X_USE_EVI;
@@ -438,7 +497,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		tmp2 += !(priv->vilist[tmp1++].flags && GGI_X_VI_NON_FB);
 	}
 	if (!tmp2) {
-		GGIDPRINT("X: No acceptable X11 visuals.\n");
+		DPRINT("X: No acceptable X11 visuals.\n");
 		err = GGI_ENOFUNC;
 		goto out;
 	}
@@ -458,8 +517,8 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		goto nomansync;
 	}
 	if (!priv->createfb) {
-		priv->createfb = _ggi_x_create_ximage;
-		priv->freefb = _ggi_x_free_ximage;
+		priv->createfb = _ggi_x_createfb;
+		priv->freefb = _ggi_x_freefb;
 	}
 
 	/* See if we want/need/have mansync */
@@ -472,7 +531,8 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 	if (priv->opmansync == NULL) {
 		goto out;
 	}
-	err = _ggiAddDL(vis, "helper-mansync", NULL, priv->opmansync, 0);
+	err = _ggiAddDL(vis, _ggiGetConfigHandle(),
+			"helper-mansync", NULL, priv->opmansync, 0);
 	if (err) {
 		fprintf(stderr,
 			"display-X: Cannot load required helper-mansync!\n");
@@ -482,18 +542,18 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
  nomansync:
 	if (options[OPT_NOACCEL].result[0] != 'n') {
 		if (priv->createfb == NULL) {
-			GGIDPRINT("X: No rendering path!\n");
+			DPRINT("X: No rendering path!\n");
 			err = GGI_ENODEVICE;
 			goto out;
 		}
-		GGIDPRINT("disabling drawable\n");
+		DPRINT("disabling drawable\n");
 		priv->createdrawable = NULL;
 	}
 
 	if (priv->createdrawable != NULL) {
 		priv->textfont = XLoadQueryFont(disp, "fixed");
 		if (priv->textfont != NULL) {
-			GGIDPRINT_MISC("Xlib: using font with "
+			DPRINT_MISC("Xlib: using font with "
 				       "dimension %dx%d\n",
 				       priv->textfont->max_bounds.width,
 				       priv->textfont->max_bounds.ascent
@@ -501,7 +561,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		}
         }
 
-	if (tolower((int)options[OPT_NOINPUT].result[0]) == 'n') {
+	if (tolower((uint8_t)options[OPT_NOINPUT].result[0]) == 'n') {
 		gii_inputxwin_arg _args;
 		gii_input *inp;
                 
@@ -514,13 +574,16 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
       /* _args.resizefunc = (gii_inputxwin_resizefunc*)GGI_X_resize;*/
 		_args.resizefunc = NULL;
                 _args.resizearg = vis;
-		_args.gglock = lock;
+		_args.lockfunc = (gii_inputxwin_lockfunc*)priv->lock_xlib;
+                _args.lockarg = vis;
+		_args.unlockfunc = (gii_inputxwin_unlockfunc*)priv->unlock_xlib;
+                _args.unlockarg = vis;
                 
 		inp = giiOpen("xwin", &_args, NULL);
-		GGIDPRINT_MISC("X: giiOpen returned with %p\n", inp);
+		DPRINT_MISC("X: giiOpen returned with %p\n", inp);
 
 		if (inp == NULL) {
-			GGIDPRINT_MISC("Unable to open xwin inputlib\n");
+			DPRINT_MISC("Unable to open xwin inputlib\n");
 			GGIclose(vis, dlh);
 			return GGI_ENODEVICE;
 		}
@@ -541,7 +604,7 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 		}
 	}
 
-	GGIDPRINT_MISC("X-target fully up\n");
+	DPRINT_MISC("X-target fully up\n");
 
 	*dlret = GGI_DL_OPDISPLAY;
 	return 0;
@@ -554,8 +617,8 @@ static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
 
 static int GGIexit(ggi_visual *vis, struct ggi_dlhandle *dlh)
 {
-	LIBGGI_ASSERT(vis != NULL, "GGIexit: vis == NULL");
-	LIBGGI_ASSERT(GGIX_PRIV(vis) != NULL, "GGIexit: GGIX_PRIV(vis) == NULL");
+	LIB_ASSERT(vis != NULL, "GGIexit: vis == NULL");
+	LIB_ASSERT(GGIX_PRIV(vis) != NULL, "GGIexit: GGIX_PRIV(vis) == NULL");
 
 	if (GGIX_PRIV(vis)->opmansync) {
 		if (!(LIBGGI_FLAGS(vis) & GGIFLAG_ASYNC)) {
@@ -573,13 +636,13 @@ int GGIdl_X(int func, void **funcptr)
 {
 	switch (func) {
 	case GGIFUNC_open:
-		*funcptr = GGIopen;
+		*funcptr = (void *)GGIopen;
 		return 0;
 	case GGIFUNC_exit:
-		*funcptr = GGIexit;
+		*funcptr = (void *)GGIexit;
 		return 0;
 	case GGIFUNC_close:
-		*funcptr = GGIclose;
+		*funcptr = (void *)GGIclose;
 		return 0;
 	default:
 		*funcptr = NULL;
