@@ -1,4 +1,4 @@
-/* $Id: color.c,v 1.8.2.1 2004/11/14 20:57:34 cegger Exp $
+/* $Id: color.c,v 1.11 2005/01/23 21:57:20 nsouch Exp $
 ******************************************************************************
 
    Display-FBDEV
@@ -33,6 +33,7 @@
 
 #include "config.h"
 #include <ggi/internal/ggi-dl.h>
+#include <ggi/internal/ggi_debug.h>
 #include "kgi/config.h"
 #include <ggi/display/kgi.h>
 
@@ -43,10 +44,10 @@ GGI_kgi_setPalette(ggi_visual *vis, size_t start, size_t len, const ggi_color *c
 	kgic_ilut_set_request_t ilut;
 	size_t nocols = 1 << GT_DEPTH(LIBGGI_GT(vis));
 
-	LIBGGI_APPASSERT(colormap != NULL,
+	APP_ASSERT(colormap != NULL,
 			 "GGI_kgi_setPalette() - colormap == NULL");
 
-	GGIDPRINT_COLOR("display-kgi: SetPalVec(%d,%d)\n", start, len);
+	DPRINT_COLOR("display-kgi: SetPalVec(%d,%d)\n", start, len);
 	
 	if (start == (size_t)GGI_PALETTE_DONTCARE) {
 		start = 0;
@@ -73,7 +74,7 @@ GGI_kgi_setPalette(ggi_visual *vis, size_t start, size_t len, const ggi_color *c
 	}
 
 	if (ioctl(KGI_CTX(vis).mapper.fd, KGIC_RESOURCE_CLUT_SET, &ilut) < 0) {
-		GGIDPRINT_COLOR("display-kgi: PUTCMAP failed.");
+		DPRINT_COLOR("display-kgi: PUTCMAP failed.");
 		return -1;
 	}
 
