@@ -1,4 +1,4 @@
-/* $Id: color.c,v 1.3.2.2 2004/11/14 20:55:36 cegger Exp $
+/* $Id$
 ******************************************************************************
 
    Display-lcd823
@@ -31,16 +31,17 @@
 #include <sys/ioctl.h>
 
 #include <ggi/display/lcd823.h>
+#include <ggi/internal/ggi_debug.h>
 
 
 int
 GGI_lcd823_setPalette(ggi_visual *vis, size_t start, size_t size, const ggi_color *colormap)
 {
-	uint16          *pal  = (uint16*)(LIBGGI_PAL(vis)->priv);
+	uint16_t          *pal  = (uint16_t*)(LIBGGI_PAL(vis)->priv);
 	size_t nocols = 1 << GT_DEPTH(LIBGGI_GT(vis));
 	size_t i;
 
-	GGIDPRINT_COLOR("GGI_lcd823_setPalette(%p, %d, %d)\n", vis, start, size);
+	DPRINT_COLOR("GGI_lcd823_setPalette(%p, %d, %d)\n", vis, start, size);
 
 	if (start < 0 || start+size > nocols) {
 		return GGI_ENOSPACE;
@@ -61,5 +62,5 @@ GGI_lcd823_setPalette(ggi_visual *vis, size_t start, size_t size, const ggi_colo
 
 size_t GGI_lcd823_getPrivSize(ggi_visual_t vis)
 {
-  return (256 * sizeof(uint16));
+  return (256 * sizeof(uint16_t));
 }
