@@ -1,4 +1,4 @@
-/* $Id$
+/* $Id: box.c,v 1.12 2005/07/30 10:58:27 cegger Exp $
 ******************************************************************************
 
    TELE target.
@@ -109,13 +109,13 @@ int GGI_tele_getpixel(ggi_visual *vis, int x, int y, ggi_pixel *col)
 /* ---------------------------------------------------------------------- */
 
 
-int GGI_tele_putbox(ggi_visual *vis, int x, int y, int w, int h, void *buf)
+int GGI_tele_putbox(ggi_visual *vis, int x, int y, int w, int h, const void *buf)
 {
 	ggi_tele_priv *priv = TELE_PRIV(vis);
 	TeleCmdGetPutData *p;
 	TeleEvent ev;
 
-	uint8 *src = (uint8 *)(buf);
+	const uint8_t *src = (const uint8_t *)(buf);
 	int srcwidth = w;
 	int stride = w * BYTES_PER_PIXEL(vis);
 
@@ -140,7 +140,7 @@ int GGI_tele_putbox(ggi_visual *vis, int x, int y, int w, int h, void *buf)
 		int ww = (w < xstep) ? w : xstep;
 		int hh = (h < ystep) ? h : ystep;
 
-		uint8 *dest;
+		uint8_t *dest;
 
 		if (curx + ww > w)
 			ww = w - curx;
@@ -153,7 +153,7 @@ int GGI_tele_putbox(ggi_visual *vis, int x, int y, int w, int h, void *buf)
 		p->width  = ww;
 		p->height = hh;
 
-		dest = (uint8 *)(p->pixel);
+		dest = (uint8_t *)(p->pixel);
 
 		for (j = 0; j < hh; j++) {
 		  memcpy(&(dest[j * ww * BYTES_PER_PIXEL(vis)]),
@@ -192,7 +192,7 @@ int GGI_tele_getbox(ggi_visual *vis, int x, int y, int w, int h, void *buf)
 	TeleCmdGetPutData *p;
 	TeleEvent ev;
 
-	uint8 *dest = (uint8 *)buf;
+	uint8_t *dest = (uint8_t *)buf;
 	int stride = w * BYTES_PER_PIXEL(vis);
 
 	int xstep, ystep;
@@ -222,7 +222,7 @@ int GGI_tele_getbox(ggi_visual *vis, int x, int y, int w, int h, void *buf)
 		int ww = (w < xstep) ? w : xstep;
 		int hh = (h < ystep) ? h : ystep;
 
-		uint8 *src;
+		uint8_t *src;
 
 		if (curx + ww > w)
 			ww = w - curx;
@@ -247,7 +247,7 @@ int GGI_tele_getbox(ggi_visual *vis, int x, int y, int w, int h, void *buf)
 		tele_receive_reply(vis, &ev, TELE_CMD_GETBOX, 
 					ev.sequence);
 
-		src = (uint8 *)p->pixel;
+		src = (uint8_t *)p->pixel;
 
 		for(j = 0; j < hh; ++j) {
 		  memcpy(&(dest[(j*stride + curx)]),
@@ -330,13 +330,13 @@ int GGI_tele_putpixel(ggi_visual *vis, int x, int y, ggi_pixel col)
 }	/* GGI_tele_putpixel */
 
 
-int GGI_tele_puthline(ggi_visual *vis, int x, int y, int w, void *buf)
+int GGI_tele_puthline(ggi_visual *vis, int x, int y, int w, const void *buf)
 {
 	return GGI_tele_putbox(vis, x, y, w, 1, buf);
 }	/* GGI_tele_puthline */
 
 
-int GGI_tele_putvline(ggi_visual *vis, int x, int y, int h, void *buf)
+int GGI_tele_putvline(ggi_visual *vis, int x, int y, int h, const void *buf)
 {
 	return GGI_tele_putbox(vis, x, y, 1, h, buf);
 }	/* GGI_tele_putvline */
